@@ -198,7 +198,7 @@ NCZ_noop_codec_to_hdf5(const char* codec_json, size_t* nparamsp, unsigned** para
     if(jtmp == NULL || !NCJisatomic(jtmp)) {stat = NC_EINVAL; goto done;}
     if(strcmp(NCJstring(jtmp),NCZ_noop_codec.codecid)!=0) {stat = NC_EINVAL; goto done;}
   
-    nparams = (NCJlength(jcodec) - 1) / 2; /* -1 for id each param is key+value */
+    nparams = (NCJarraylength(jcodec) - 1) / 2; /* -1 for id each param is key+value */
 
     if((params = (unsigned*)calloc(nparams,sizeof(unsigned)))== NULL)
         {stat = NC_ENOMEM; goto done;}
